@@ -1,5 +1,5 @@
 /*
- * @(#)$Id: acconfig.h,v 1.38 2007/08/22 21:57:16 jnelson Exp $
+ * @(#)$Id: acconfig.h,v 1.42 2008/06/26 04:23:09 jnelson Exp $
  */
 
 /*
@@ -401,3 +401,24 @@
 /* Define this if you have iconv_open() */
 #undef HAVE_ICONV
 
+/* Define this if you have iconv_open() */
+#undef HAVE_LIBARCHIVE
+
+/* Define this if you have strptime() */
+#undef HAVE_STRPTIME
+
+/* Define this if your <term.h> requires <curses.h> (x/open curses) */
+#undef TERM_H_REQUIRES_CURSES_H
+
+/* Define this if your <term.h> can't be used */
+#undef DONT_USE_TERM_H
+
+/* Define this if you have tcsetpgrp() */
+#undef HAVE_TCSETPGRP
+
+/* Define this if you have no posix-like job control */
+#undef NO_JOB_CONTROL
+
+/* Define this if you want wserv support */
+#undef WSERV_SUPPORT
+
