@@ -7,7 +7,8 @@
 #define __COMPAT_H__
 
 #ifndef HAVE_TPARM
-char *tparm (const char *, ...);
+char *my_tparm (const char *, ...);
+#define tparm my_tparm
 #endif
 
 #ifndef HAVE_STRTOUL
@@ -55,6 +56,9 @@ char *	my_realpath (const char *, char x[MAXPATHLEN]);
 #endif
 
 #ifndef HAVE_STRTOIMAX
+#ifdef strtoimax
+#undef strtoimax
+#endif
 long	strtoimax (const char *, char **, int);
 #endif
 
