@@ -87,6 +87,7 @@ enum HOOK_TYPES {
 	SERVER_NOTICE_LIST,
 	SERVER_STATUS_LIST,
 	SET_LIST,
+	SIGNAL_LIST,
 	SIGNOFF_LIST,
 	SILENCE_LIST,
 	SSL_SERVER_CERT_LIST,
@@ -105,6 +106,7 @@ enum HOOK_TYPES {
 	WINDOW_CREATE_LIST,
 	WINDOW_BEFOREKILL_LIST,
 	WINDOW_KILL_LIST,
+	WINDOW_NOTIFIED_LIST,
 	WINDOW_SERVER_LIST,
 	YELL_LIST,
 	ZZZZ_THIS_ALWAYS_COMES_LAST_ZZZZ
