@@ -1,4 +1,4 @@
-/* $EPIC: commands.c,v 1.182 2008/05/15 18:04:24 alex Exp $ */
+/* $EPIC: commands.c,v 1.186 2008/11/30 19:09:23 jnelson Exp $ */
 /*
  * commands.c -- Stuff needed to execute commands in ircII.
  *		 Includes the bulk of the built in commands for ircII.
@@ -1925,7 +1925,7 @@ static void	loader_std (struct epic_loadfile *elf, const char *filename, const c
 
 			if (!paste_level)
 			{
-				error("Unexpected } in %s, line %d",
+				my_error("Unexpected } in %s, line %d",
 					filename, loadinfo->line);
 				break;
 			}
@@ -1982,14 +1982,14 @@ static void	loader_std (struct epic_loadfile *elf, const char *filename, const c
 	} /* End of for(;;line++) */
 
 	if (in_comment)
-	    error("File %s ended with an unterminated comment in line %d",
+	    my_error("File %s ended with an unterminated comment in line %d",
 			filename, comment_line);
 
 	if (current_row)
 	{
 	    if (paste_level)
 	    {
-		error("Unexpected EOF in %s trying to match '{' at line %d",
+		my_error("Unexpected EOF in %s trying to match '{' at line %d",
 				filename, paste_line);
 	        new_free(&current_row);
 	    }
@@ -2046,14 +2046,14 @@ static void	loader_pf (struct epic_loadfile *elf, const char *filename, const ch
 {
 	char *	buffer;
 	int	bufsize, pos;
-	int	this_char, newline, comment, shebang;
+	int	this_char, my_newline, comment, shebang;
 
 	loadinfo->loader = "pf";
 
 	bufsize = 8192;
 	buffer = new_malloc(bufsize);
 	pos = 0;
-	newline = 1;
+	my_newline = 1;
 	comment = 0;
 	shebang = 0;
 
@@ -2090,7 +2090,7 @@ static void	loader_pf (struct epic_loadfile *elf, const char *filename, const ch
 	    {
 		/* At a newline, turn on eol handling, turn off comment. */
 		if (this_char == '\n') {
-		    newline = 1;
+		    my_newline = 1;
 		    comment = 0;
 		    break;
 		}
@@ -2100,21 +2100,21 @@ static void	loader_pf (struct epic_loadfile *elf, const char *filename, const ch
 		    break;
 
 		/* If we last saw an eol, ignore any following spaces */
-		if (newline && isspace(this_char))
+		if (my_newline && isspace(this_char))
 		    break;
 
 		/* If we last saw an eol, a # starts a one-line comment. */
-		if (newline && this_char == '#') {
+		if (my_newline && this_char == '#') {
 		    comment = 1;
 		    break;
 		}
 
 		/* If the last thing we saw was a newline, put a space here */
-		if (newline && pos > 0)
+		if (my_newline && pos > 0)
 		    buffer[pos++] = ' ';
 
 		/* We are no longer at a newline */
-		newline = 0;
+		my_newline = 0;
 
 		/* Append this character to the buffer */
 		buffer[pos++] = this_char;
@@ -3096,6 +3096,9 @@ struct target_type target[4] =
 	    else if (*current_nick == '@' && toupper(current_nick[1]) == 'W' 
 			&& is_number(current_nick + 1))
 		target_file_write(current_nick + 1, text);
+	    else if (*current_nick == '@' && toupper(current_nick[1]) == 'L' 
+			&& is_number(current_nick + 1))
+		target_file_write(current_nick + 1, text);
 
 	    else if (*current_nick == '"')
 		send_to_server("%s", text);
@@ -3339,7 +3342,10 @@ static void	eval_inputlist (char *args, char *line)
 {
         char *tmp;
 	if (args[0]=='(') {
-                tmp=next_expr(&args, '(');
+                if (!(tmp = next_expr(&args, '('))) {
+			yell("INPUT: syntax error with arglist");
+			return;
+		}
                 runcmds_with_arglist(args, tmp, line);
 	} else {
                 /* traditional behavior */
