@@ -1,4 +1,4 @@
-/* $EPIC: ctcp.c,v 1.56 2007/09/07 18:07:29 jnelson Exp $ */
+/* $EPIC: ctcp.c,v 1.58 2008/06/23 21:25:03 jnelson Exp $ */
 /*
  * ctcp.c:handles the client-to-client protocol(ctcp). 
  *
@@ -53,7 +53,7 @@
 #include "status.h"
 #include "vars.h"
 #include "window.h"
-#include "if.h"
+#include "ifcmd.h"
 #include "flood.h"
 #include "words.h"
 
@@ -260,10 +260,20 @@ CTCP_HANDLER(do_utc)
 CTCP_HANDLER(do_atmosphere)
 {
 	int	l;
+	int	flag, fflag;
 
 	if (!cmd || !*cmd)
 		return NULL;
 
+	/* Xavier mentioned that we should allow /ignore #chan action */
+	flag = check_ignore_channel(from, FromUserHost, to, LEVEL_ACTION);
+	fflag = new_check_flooding(from, FromUserHost, 
+					is_channel(to) ? to : NULL,
+					cmd, LEVEL_ACTION);
+
+	if (flag == IGNORED || fflag == 1)
+		return NULL;
+
 	if (is_channel(to))
 	{
 		l = message_from(to, LEVEL_ACTION);
