@@ -1,4 +1,4 @@
-/* $EPIC: exec.c,v 1.41 2007/06/25 22:09:29 jnelson Exp $ */
+/* $EPIC: exec.c,v 1.44 2008/04/05 00:20:38 jnelson Exp $ */
 /*
  * exec.c: handles exec'd process for IRCII 
  *
@@ -49,7 +49,27 @@
 #include "output.h"
 #include "parse.h"
 #include "newio.h"
-#include "if.h"
+#include "ifcmd.h"
+
+#ifdef NO_JOB_CONTROL
+BUILT_IN_COMMAND(execcmd)
+{ 
+	say("Your system does not support job control, sorry.");
+	return; 
+}
+int	get_child_exit (pid_t x)			{ return -1; }
+void	clean_up_processes (void)			{ return; }
+int	text_to_process (int x, const char *y, int z) 	
+{ 
+	say("Cannot send text to process without job control, sorry.");
+	return 1; 
+}
+void	exec_server_delete (int x)			{ return; }
+void	add_process_wait (int x, const char *y)		{ return; }
+int	get_process_index (char **x)			{ return -1; }
+int	is_valid_process (const char *x)		{ return -1; }
+int	process_is_running (char *x)			{ return 0; }
+#else
 
 #include <sys/wait.h>
 #include <sys/ioctl.h>
@@ -500,6 +520,12 @@ say("Output from process %d (%s) now going to you", i, proc->name);
 		{
 		case -1:
 			say("Couldn't start new process!");
+			close(p0[0]);
+			close(p0[1]);
+			close(p1[0]);
+			close(p1[1]);
+			close(p2[0]);
+			close(p2[1]);
 			break;
 
 		/*
@@ -1401,3 +1427,5 @@ int		process_is_running (char *arg)
 	else
 		return 1;
 }
+
+#endif
