@@ -1,4 +1,4 @@
-/* $EPIC: input.c,v 1.55 2008/05/09 16:26:34 alex Exp $ */
+/* $EPIC: input.c,v 1.60 2008/11/26 03:26:34 jnelson Exp $ */
 /*
  * input.c: does the actual input line stuff... keeps the appropriate stuff
  * on the input line, handles insert/delete of characters/words... the whole
@@ -94,7 +94,8 @@ InputItem *	new_input_item (wchar_t wc)
 	ii->prev = NULL;
 	ii->character = wc;
 	ii->column = -1;
-	ii->num_columns = wcwidth(wc);
+	/* ii->num_columns = wcwidth(wc); */
+	ii->num_columns = 1;
 }
 
 void	delete_input_item (InputItem **ii)
@@ -117,7 +118,7 @@ void	add_item_to_input (InputItem *prev, InputItem *item)
 	renumber_columns(item);
 }
 
-void	renumber_columns (InputItem *item);
+void	renumber_columns (InputItem *item)
 {
 	for (; item; item = item->next)
 	    item->column = item->prev->column + item->prev->num_columns;
@@ -141,6 +142,254 @@ void	set_cut_anchor (InputItem *i)
 void	cut_input_line (InputItem *first, InputItem *last)
 {
 }
+
+/*************************************************************/
+/*
+ * add_codepoint_to_input
+ * input: codepoint -- the codepoint to insert into the input line
+ * 1) Convert codepoint into an InputItem
+ * 2) Insert it in place of, or after, the cursor
+ * 3) Update the logical cursor
+ * 4) Update the physical display
+ */
+void	add_codepoint_to_input (long codepoint)
+{
+}
+
+/*
+ * assemble_input_line
+ * param: s -- The screen whose input line is to be assembled
+ *        result -- Where the assembled input line shall be put
+ *        len -- How big the assembled input line is.
+ * 1) Transform each InputItem into a string of the appropriate encoding
+ * 2) Catenate all of these encoded strings together into 'result'
+ * 3) 'len' is the number of bytes in ``result''.
+ *
+ * Note: `result' is not necessarily a C string!  Unless the output 
+ *	  encoding being used is a C string encoding (ie, utf8)
+ * Note: `result' always ends with a nul, but that does not mean that
+ *       the first nul is this trailing nul (for some encodings, like
+ *	 ucs16, it definitely will not be!)
+ */
+size_t	assemble_input_line (Screen *s, char **result, size_t *len)
+{
+}
+
+static int 	input_puts (InputItem *i, int numcols, int echo) 
+{
+}
+
+void 	cursor_to_input (void)
+{
+}
+
+void	update_input (void *which_screen, int update)
+{
+}
+
+void 	change_input_prompt (int direction)
+{
+}
+
+void	input_move_cursor (int dir, int refresh)
+{
+}
+
+void	set_input (const char *str)
+{
+}
+
+char *	get_input (void)
+{
+}
+
+void	init_input (void)
+{
+}
+
+char *	get_input_prompt (void)
+{
+}
+
+void	set_input_prompt (void *stuff)
+{
+}
+
+BUILT_IN_KEYBINDING(input_forward_word)
+{
+}
+
+/* input_backward_word: move the cursor left on word in the input line */
+BUILT_IN_KEYBINDING(input_backward_word)
+{
+}
+
+/*
+ * input_delete_character -- Deletes the character currently under the
+ * 			     input cursor.
+ */
+BUILT_IN_KEYBINDING(input_delete_character)
+{
+}
+
+
+/*
+ * input_backspace -- Basically a combination of backward_character and
+ *		      delete_character.  No, this is not significantly
+ *		      more expensive than the old way.
+ */
+BUILT_IN_KEYBINDING(input_backspace)
+{
+}
+
+/*
+ * input_beginning_of_line: moves the input cursor to the first character in
+ * the input buffer 
+ */
+BUILT_IN_KEYBINDING(input_beginning_of_line)
+{
+}
+
+/*
+ * input_end_of_line: moves the input cursor to the last character in the
+ * input buffer 
+ */
+BUILT_IN_KEYBINDING(input_end_of_line)
+{
+}
+
+/*
+ * This removes every character from the 'anchor' position to the current
+ * position from the input line, and puts it into the cut buffer.  It does
+ * the requisite redraw as well.
+ */
+static void	cut_input (int anchor)
+{
+}
+
+/*
+ * To visualize:
+ *
+ *		This is the input buffer
+ *			  ^			(the input cursor)
+ * orig_pos points to the 'e'.
+ * c is an 'e'.
+ * LOGICAL_CURSOR is moved to the space between the 's' and the 't'.
+ * The input buffer is changed to:
+ *
+ *		This is e input buffer
+ *			^			(the input cursor)
+ */
+BUILT_IN_KEYBINDING(input_delete_to_previous_space)
+{
+}
+
+/*
+ * input_delete_previous_word: deletes from the cursor backwards to the next
+ * space character.  This is probably going to be the same effect as 
+ * delete_to_previous_space, but hey -- you know.
+ */
+BUILT_IN_KEYBINDING(input_delete_previous_word)
+{
+}
+
+/*
+ * input_delete_next_word: deletes from the cursor to the end of the next
+ * word 
+ */
+BUILT_IN_KEYBINDING(input_delete_next_word)
+{
+}
+
+/*
+ * input_add_character: adds the character c to the input buffer, repecting
+ * the current overwrite/insert mode status, etc 
+ */
+BUILT_IN_KEYBINDING(input_add_character)
+{
+}
+
+/* input_clear_to_eol: erases from the cursor to the end of the input buffer */
+BUILT_IN_KEYBINDING(input_clear_to_eol)
+{
+}
+
+/*
+ * input_clear_to_bol: clears from the cursor to the beginning of the input
+ * buffer 
+ */
+BUILT_IN_KEYBINDING(input_clear_to_bol)
+{
+}
+
+/*
+ * input_clear_line: clears entire input line
+ */
+BUILT_IN_KEYBINDING(input_clear_line)
+{
+}
+
+/*
+ * input_reset_line: clears entire input line, suitable for use in tabscripts
+ * This does not mangle the cutbuffer, so you can use it to replace the input
+ * line w/o any deleterious effects!
+ */
+BUILT_IN_KEYBINDING(input_reset_line)
+{
+}
+
+
+/*
+ * input_transpose_characters: move the character before the cursor to
+ * the position after the cursor.
+ */
+BUILT_IN_KEYBINDING(input_transpose_characters)
+{
+}
+
+
+BUILT_IN_KEYBINDING(refresh_inputline)
+{
+}
+
+/*
+ * input_yank_cut_buffer: takes the contents of the cut buffer and inserts it
+ * into the input line 
+ */
+BUILT_IN_KEYBINDING(input_yank_cut_buffer)
+{
+}
+
+
+/* used with input_move_cursor */
+#define RIGHT 1
+#define LEFT 0
+
+/* BIND functions: */
+BUILT_IN_KEYBINDING(forward_character)
+{
+}
+
+BUILT_IN_KEYBINDING(backward_character)
+{
+}
+
+/*
+ * The SEND_LINE function (the <enter> key):
+ *  1) Assemble the current input line,
+ *  2a) If the window is prompting a user, do the callback
+ *  2b) Otherwise, Hook /on input, or run parse_statement().
+ *  3) If the window is holding, unhold it
+ *  4) If the window is scrolling back and holding, scroll down
+ */
+BUILT_IN_KEYBINDING(send_line)
+{
+}
+
+/****************************************************************************/
+
+
+
 #endif
 
 /* 
@@ -357,7 +606,7 @@ void	update_input (void *which_screen, int update)
 
                         new_free(&ptr);
 
-                        /*ptr_free = expand_alias(get_string_var(INPUT_INDICATOR_RIGHT_VAR), empty_string);
+                        ptr_free = expand_alias(get_string_var(INPUT_INDICATOR_RIGHT_VAR), empty_string);
                         ptr = new_normalize_string(ptr_free, 0, display_line_mangler);
                         new_free(&ptr_free);
 
@@ -368,7 +617,7 @@ void	update_input (void *which_screen, int update)
                                 update = UPDATE_ALL;
                         }
 
-                        new_free(&ptr);*/
+                        new_free(&ptr);
 		}
 
 
@@ -439,10 +688,18 @@ void	update_input (void *which_screen, int update)
                          * and output the rest of the input buffer.
                          */
                         term_echo(do_echo);
-                        safe_puts(&INPUT_BUFFER[START],
-				  last_input_screen->co - cols_used, do_echo);
 
-			/*
+                        if (INPUT_BUFFER[START + last_input_screen->co - cols_used]) {
+				cols_used+=IND_RIGHT_LEN;
+				safe_puts(&INPUT_BUFFER[START],
+					  last_input_screen->co - cols_used, do_echo);
+				output_with_count(IND_RIGHT, 0, 1);
+			} else {
+				safe_puts(&INPUT_BUFFER[START],
+					  last_input_screen->co - cols_used, do_echo);
+                        }
+
+                        /*
 			 * Clear the rest of the input line and reset the cursor
 			 * to the current input position.
 			 */
@@ -475,7 +732,14 @@ void	update_input (void *which_screen, int update)
 				max -= IND_LEFT_LEN;
 
 			term_echo(do_echo);
-			safe_puts(&(THIS_CHAR), max, do_echo);
+
+                        if (INPUT_BUFFER[LOGICAL_CURSOR+max]) {
+                                max -= IND_RIGHT_LEN;
+                                safe_puts(&(THIS_CHAR), max, do_echo);
+                                output_with_count(IND_RIGHT, 0, 1);
+                        } else {
+                                safe_puts(&(THIS_CHAR), max, do_echo);
+                        }
 			term_clear_to_eol();
 			update = UPDATE_JUST_CURSOR;
 		}
@@ -534,7 +798,8 @@ void 	change_input_prompt (int direction)
 		*INPUT_BUFFER = 0;
                 START = 0;
 		LOGICAL_CURSOR = 0;
-	}
+                memset(INPUT_BUFFER, 0, sizeof(INPUT_BUFFER));
+        }
 
 	update_input(last_input_screen, UPDATE_ALL);
 }
@@ -625,6 +890,7 @@ void	init_input (void)
 	*INPUT_BUFFER = 0;
         START = 0;
         LOGICAL_CURSOR = 0;
+        memset(INPUT_BUFFER, 0, sizeof(INPUT_BUFFER));
 }
 
 /* get_input_prompt: returns the current input_prompt */
@@ -691,15 +957,15 @@ BUILT_IN_KEYBINDING(input_backward_word)
 	cursor_to_input();
 
 	/* If already at the start of a word, move back a position */
-	if (!WHITESPACE(THIS_CHAR) && WHITESPACE(PREV_CHAR))
+        if (!WHITESPACE(THIS_CHAR) && WHITESPACE(PREV_CHAR) && (LOGICAL_CURSOR > 0))
 		input_move_cursor(-1, 1);
 
 	/* Move to the start of the current whitespace */
-	while ((THIS_CHAR) && WHITESPACE(THIS_CHAR))
+	while (/*(THIS_CHAR) &&*/ WHITESPACE(THIS_CHAR) && (LOGICAL_CURSOR > 0))
 		input_move_cursor(-1, 1);
 
 	/* Move to the start of the current word */
-	while ((THIS_CHAR) && !WHITESPACE(THIS_CHAR))
+	while (/*(THIS_CHAR) &&*/ !WHITESPACE(THIS_CHAR) && (LOGICAL_CURSOR > 0))
 		input_move_cursor(-1, 1);
 
 	/* If we overshot our goal, then move forward */
@@ -845,7 +1111,7 @@ BUILT_IN_KEYBINDING(input_delete_previous_word)
 
 	cursor_to_input();
 
-	if (LOGICAL_CURSOR <= 0)
+        if (LOGICAL_CURSOR <= 0)
 		return;
 
 	anchor = LOGICAL_CURSOR;
@@ -954,7 +1220,8 @@ BUILT_IN_KEYBINDING(input_clear_line)
 	*INPUT_BUFFER = 0;
         START = 0;
         LOGICAL_CURSOR=0;
-	update_input(last_input_screen, UPDATE_FROM_CURSOR);
+        memset(INPUT_BUFFER, 0, sizeof(INPUT_BUFFER));
+        update_input(last_input_screen, UPDATE_FROM_CURSOR);
 }
 
 /*
@@ -967,8 +1234,9 @@ BUILT_IN_KEYBINDING(input_reset_line)
 	*INPUT_BUFFER = 0;
 	START = 0;
         LOGICAL_CURSOR=0;
+        memset(INPUT_BUFFER, 0, sizeof(INPUT_BUFFER));
 
-	if (!string)
+        if (!string)
 		set_input(empty_string);
 	else
 		set_input(string);	/* This calls update_input() */
@@ -1068,6 +1336,7 @@ BUILT_IN_KEYBINDING(send_line)
 	*INPUT_BUFFER = 0;
         START = 0;
         LOGICAL_CURSOR = 0;
+        memset(INPUT_BUFFER, 0, sizeof(INPUT_BUFFER));
 
 	update_input(last_input_screen, UPDATE_ALL);
 
@@ -1136,7 +1405,7 @@ BUILT_IN_KEYBINDING(toggle_insert_mode)
 }
 
 /* This keybinding should be scripted. */
-BUILT_IN_KEYBINDING(clear_screen)
+BUILT_IN_KEYBINDING(my_clear_screen)
 {
 	clear_window_by_refnum(0, 1);
 }
@@ -1206,4 +1475,3 @@ BUILT_IN_KEYBINDING(parse_text)
 		runcmds(string, empty_string);
 	system_exception = old;
 }
-
