@@ -1,4 +1,4 @@
-/* $EPIC: lastlog.c,v 1.69 2007/08/02 16:36:58 jnelson Exp $ */
+/* $EPIC: lastlog.c,v 1.75 2008/02/16 23:42:05 jnelson Exp $ */
 /*
  * lastlog.c: handles the lastlog features of irc. 
  *
@@ -56,13 +56,19 @@ typedef struct	lastlog_stru
 	time_t	when;
 	int	visible;
 	intmax_t refnum;
-	int	winref;
+	unsigned winref;
 }	Lastlog;
 
 static	intmax_t global_lastlog_refnum = 0;
 
-static int	show_lastlog (Lastlog **l, int *skip, int *number, Mask *level_mask, char *match, regex_t *reg, int *max, const char *target, int mangler);
-static void	remove_lastlog_item (Window *window, Lastlog *being_removed);
+static int	show_lastlog (Lastlog **l, int *skip, int *number, Mask *level_mask, char *match, regex_t *reg, int *max, const char *target, int mangler, unsigned winref);
+static int	oldest_lastlog_for_window (Lastlog **item, unsigned winref);
+static int	newer_lastlog_entry (Lastlog **item, unsigned winref);
+static int	older_lastlog_entry (Lastlog **item, unsigned winref);
+static int	newest_lastlog_for_window (Lastlog **item, unsigned winref);
+static void	remove_lastlog_item (Lastlog *item);
+static void	switch_lastlog_window (Lastlog *item, unsigned newref);
+static void	move_lastlog_item (Lastlog *item, unsigned newref);
 
 Lastlog *	lastlog_oldest = NULL;
 Lastlog *	lastlog_newest = NULL;
@@ -87,11 +93,13 @@ void	set_lastlog_mask (void *stuff)
 {
 	VARIABLE *v;
 	const char *str;
+	char *rejects = NULL;
 
 	v = (VARIABLE *)stuff;
 	str = v->string;
 
-	str_to_mask(&lastlog_mask, str);
+	if (str_to_mask(&lastlog_mask, str, &rejects))
+		standard_level_warning("/SET LASTLOG_LEVEL", &rejects);
 	malloc_strcpy(&v->string, mask_to_str(&lastlog_mask));
 
 	current_window->lastlog_mask = lastlog_mask;
@@ -101,6 +109,7 @@ void	set_new_server_lastlog_mask (void *stuff)
 {
 	VARIABLE *v;
 	const char *str;
+	char *rejects = NULL;
 
 	v = (VARIABLE *)stuff;
 	str = v->string;
@@ -112,7 +121,8 @@ void	set_new_server_lastlog_mask (void *stuff)
 		new_server_lastlog_mask = (Mask *)new_malloc(sizeof(Mask));
 		mask_unsetall(new_server_lastlog_mask);
 	    }
-	    str_to_mask(new_server_lastlog_mask, str);
+	    if (str_to_mask(new_server_lastlog_mask, str, &rejects))
+		standard_level_warning("/SET NEW_SERVER_LASTLOG_LEVEL", &rejects);
 	    malloc_strcpy(&v->string, mask_to_str(new_server_lastlog_mask));
 	}
 	else
@@ -123,6 +133,7 @@ void	set_old_server_lastlog_mask (void *stuff)
 {
 	VARIABLE *v;
 	const char *str;
+	char *rejects = NULL;
 
 	v = (VARIABLE *)stuff;
 	str = v->string;
@@ -134,7 +145,8 @@ void	set_old_server_lastlog_mask (void *stuff)
 		old_server_lastlog_mask = (Mask *)new_malloc(sizeof(Mask));
 		mask_unsetall(old_server_lastlog_mask);
 	    }
-	    str_to_mask(old_server_lastlog_mask, str);
+	    if (str_to_mask(old_server_lastlog_mask, str, &rejects))
+		standard_level_warning("/SET OLD_SERVER_LASTLOG_LEVEL", &rejects);
 	    malloc_strcpy(&v->string, mask_to_str(old_server_lastlog_mask));
 	}
 	else
@@ -155,11 +167,13 @@ void	set_notify_mask (void *stuff)
 {
 	VARIABLE *v;
 	const char *str;
+	char *rejects = NULL;
 
 	v = (VARIABLE *)stuff;
 	str = v->string;
 
-	str_to_mask(&notify_mask, str);
+	if (str_to_mask(&notify_mask, str, &rejects))
+		standard_level_warning("/SET NOTIFY_LEVEL", &rejects);
 	malloc_strcpy(&v->string, mask_to_str(&notify_mask));
 
 	current_window->notify_mask = notify_mask;
@@ -169,11 +183,13 @@ void	set_current_window_mask (void *stuff)
 {
 	VARIABLE *v;
 	const char *str;
+	char *rejects = NULL;
 
 	v = (VARIABLE *)stuff;
 	str = v->string;
 
-	str_to_mask(&current_window_mask, str);
+	if (str_to_mask(&current_window_mask, str, &rejects))
+		standard_level_warning("/SET CURRENT_WINDOW_LEVEL", &rejects);
 	malloc_strcpy(&v->string, mask_to_str(&current_window_mask));
 }
 
@@ -194,10 +210,11 @@ intmax_t	add_to_lastlog (Window *window, const char *line)
 
 	new_l = (Lastlog *)new_malloc(sizeof(Lastlog));
 	new_l->refnum = global_lastlog_refnum++;
-	new_l->older = window->lastlog_newest;
+	new_l->older = lastlog_newest;
 	new_l->newer = NULL;
 	new_l->level = who_level;
 	new_l->msg = malloc_strdup(line);
+	new_l->winref = window->refnum;
 	if (who_from)
 		new_l->target = malloc_strdup(who_from);
 	else
@@ -205,12 +222,12 @@ intmax_t	add_to_lastlog (Window *window, const char *line)
 	time(&new_l->when);
 
 	/* * * */
-	if (window->lastlog_newest)
-		window->lastlog_newest->newer = new_l;
-	window->lastlog_newest = new_l;
+	if (lastlog_newest)
+		lastlog_newest->newer = new_l;
+	lastlog_newest = new_l;
 
-	if (!window->lastlog_oldest)
-		window->lastlog_oldest = window->lastlog_newest;
+	if (!lastlog_oldest)
+		lastlog_oldest = lastlog_newest;
 
 	if (mask_isset(&window->lastlog_mask, who_level))
 	{
@@ -228,66 +245,20 @@ intmax_t	add_to_lastlog (Window *window, const char *line)
 
 void 	trim_lastlog (Window *window)
 {
-	while (window->lastlog_oldest)
+	Lastlog *item = NULL;
+
+	while (window->lastlog_size > window->lastlog_max)
 	{
-		/* All done! */
-		if (window->lastlog_size <= window->lastlog_max)
-			return;
-
-		remove_lastlog_item(window, window->lastlog_oldest);
-	}
-
-	/* Uh, the lastlog must be empty... */
-	window->lastlog_size = 0;
-}
-
-void	omit_from_lastlog (Window *window, const char *string)
-{
-	Lastlog *item;
-
-	item = window->lastlog_oldest;
-	while (item)
-	{
-		if (stristr(item->msg, string))
+		item = NULL;
+		if (oldest_lastlog_for_window(&item, window->refnum))
 		{
-			remove_lastlog_item(window, item);
-			item = window->lastlog_oldest;	/* Start over */
-			break;
+			if (item->visible)
+				window->lastlog_size--;
+			remove_lastlog_item(item);
 		}
 	}
 }
 
-static void	remove_lastlog_item (Window *window, Lastlog *being_removed)
-{
-	if (being_removed == window->lastlog_oldest)
-	{
-		window->lastlog_oldest = being_removed->newer;
-		if (window->lastlog_oldest)
-			window->lastlog_oldest->older = NULL;
-	}
-	else if (being_removed->older)
-		being_removed->older->newer = being_removed->newer;
-	else
-		panic(1, "Lastlog item [%s] being removed is not oldest and has no older.", being_removed->msg);
-
-	if (being_removed == window->lastlog_newest)
-	{
-		window->lastlog_newest = being_removed->older;
-		if (window->lastlog_newest)
-			window->lastlog_newest->newer = NULL;
-	}
-	else if (being_removed->newer)
-		being_removed->newer->older = being_removed->older;
-	else
-		panic(1, "Lastlog item [%s] being removed is not newest and has no newest.", being_removed->msg);
-
-	if (being_removed->visible)
-		window->lastlog_size--;
-	new_free((char **)&being_removed->msg);
-	new_free((char **)&being_removed->target);
-	new_free((char **)&being_removed);
-}
-
 /*
  * set_lastlog_size: sets up a lastlog buffer of size given.  If the lastlog
  * has gotten larger than it was before, all newer lastlog entries remain.
@@ -398,6 +369,7 @@ BUILT_IN_COMMAND(lastlog)
 	int		mangler = 0;
 	int		lc;
 	char *		rewrite = NULL;
+	unsigned	winref = current_window->refnum;
 
 	lc = message_setall(0, NULL, LEVEL_OTHER);
 	cnt = current_window->lastlog_size;
@@ -544,6 +516,20 @@ BUILT_IN_COMMAND(lastlog)
 	    {
 		rewrite = new_next_arg(args, &args);
 	    }
+	    else if (!my_strnicmp(arg, "-WINDOW", len))
+	    {
+		Window *w;
+		char *x;
+
+		x = new_next_arg(args, &args);
+		if (!(w = get_window_by_desc(x)))
+		{
+			yell("LASTLOG -WINDOW %s is not a valid window "
+				"name or number", x);
+			goto bail;
+		}
+		winref = w->refnum;
+	    }
 	    else if (!my_strnicmp(arg, "-", 1))
 	    {
 		int	i = str_to_level(arg+1);
@@ -669,16 +655,18 @@ BUILT_IN_COMMAND(lastlog)
 	 */
 	if (reverse == 0)
 	{
-	    int i;
+	    int i = 0;
 
-	    end = current_window->lastlog_newest;
-	    start = end;
-	    for (i = 0; start != current_window->lastlog_oldest; )
+	    for (start = end = lastlog_newest; start != lastlog_oldest; )
 	    {
-		if (mask_isnone(&level_mask) || (mask_isset(&level_mask, start->level)))
+		if (start->visible && start->winref == winref)
+		{
+		    if (mask_isnone(&level_mask) || 
+				(mask_isset(&level_mask, start->level)))
 			i++;
-		if (i == number)
+		    if (i == number)
 			break;
+		}
 		start = start->older;
 	    }
 
@@ -686,7 +674,7 @@ BUILT_IN_COMMAND(lastlog)
 	    for (l = start; l; (void)(l && (l = l->newer)))
 	    {
 		if (show_lastlog(&l, &skip, &number, &level_mask, 
-				match, reg, &max, target, mangler))
+				match, reg, &max, target, mangler, winref))
 		{
 		    if (counter == 0 && before > 0)
 		    {
@@ -754,16 +742,18 @@ BUILT_IN_COMMAND(lastlog)
 	}
 	else
 	{
-	    int i;
+	    int i = 0;
 
-	    start = current_window->lastlog_newest;
-	    end = start;
-	    for (i = 0; end != current_window->lastlog_oldest; )
+	    for (start = end = lastlog_newest; end != lastlog_oldest; )
 	    {
-		if (mask_isnone(&level_mask) || (mask_isset(&level_mask, start->level)))
+		if (end->visible && end->winref == winref)
+		{
+		    if (mask_isnone(&level_mask) || 
+				(mask_isset(&level_mask, end->level)))
 			i++;
-		if (i == number)
+		    if (i == number)
 			break;
+		}
 		end = end->older;
 	    }
 
@@ -771,7 +761,7 @@ BUILT_IN_COMMAND(lastlog)
 	    for (l = start; l; (void)(l && (l = l->older)))
 	    {
 		if (show_lastlog(&l, &skip, &number, &level_mask, 
-				match, reg, &max, target, mangler))
+				match, reg, &max, target, mangler, winref))
 		{
 		    if (counter == 0 && before > 0)
 		    {
@@ -851,10 +841,18 @@ bail:
  * This returns 1 if the current item pointed to by 'l' is something that
  * should be displayed based on the criteron provided.
  */
-static int	show_lastlog (Lastlog **l, int *skip, int *number, Mask *level_mask, char *match, regex_t *reg, int *max, const char *target, int mangler)
+static int	show_lastlog (Lastlog **l, int *skip, int *number, Mask *level_mask, char *match, regex_t *reg, int *max, const char *target, int mangler, unsigned winref)
 {
 	const char *str = NULL;
 
+	if ((*l)->winref != winref)
+	{
+		if (x_debug & DEBUG_LASTLOG)
+			yell("Lastlog item belongs to another window");
+		return 0;
+	}
+
+
 	if ((*l)->visible == 0)
 	{
 		if (x_debug & DEBUG_LASTLOG)
@@ -931,8 +929,11 @@ void	reconstitute_scrollback (Window *window)
 {
 	Lastlog *li;
 
-	for (li = window->lastlog_oldest; li; li = li->newer)
+	for (li = lastlog_oldest; li; li = li->newer)
+	{
+	    if (li->winref == window->refnum)
 		add_to_window_scrollback(window, li->msg, li->refnum);
+	}
 }
 	
 /*
@@ -980,18 +981,21 @@ BUILT_IN_FUNCTION(function_line, word)
 		RETURN_EMPTY;
 
 	/* Get the line from the lastlog */
-	for (start_pos = win->lastlog_newest; line; start_pos = start_pos->older)
+	for (start_pos = lastlog_newest; line; start_pos = start_pos->older)
 	{
+		if (start_pos->winref != win->refnum)
+			continue;
 		if (start_pos->visible)
 			line--;
 	}
 
 	if (!start_pos)
-		start_pos = win->lastlog_oldest;
+		start_pos = lastlog_oldest;
 	else
 		start_pos = start_pos->newer;
 
-	while (!start_pos->visible && start_pos->newer)
+	while ((start_pos->visible == 0 || start_pos->winref != win->refnum) && 
+				start_pos->newer)
 		start_pos = start_pos->newer;
 
 	/* If there are no visible lastlog items, punt */
@@ -1027,21 +1031,29 @@ BUILT_IN_FUNCTION(function_lastlog, word)
 	Mask	lastlog_levels;
 	int	line = 1;
 	size_t	rvclue = 0;
+	char *	rejects = NULL;
 
 	GET_FUNC_ARG(windesc, word);
 	GET_DWORD_ARG(pattern, word);
-	str_to_mask(&lastlog_levels, word);
+	if (str_to_mask(&lastlog_levels, word, &rejects))
+		standard_level_warning("$lastlog()", &rejects);
 
 	/* Get the current window, default to current window */
 	if (!(win = get_window_by_desc(windesc)))
 		RETURN_EMPTY;
 
-	for (iter = win->lastlog_newest; iter; iter = iter->older, line++)
+	for (iter = lastlog_newest; iter; iter = iter->older)
 	{
-		if (iter->visible)
-		    if (mask_isset(&lastlog_levels, iter->level))
-			if (wild_match(pattern, iter->msg))
-				malloc_strcat_word_c(&retval, space, ltoa(line), DWORD_NO, &rvclue);
+		if (iter->winref != win->refnum)
+			continue;
+		if (iter->visible == 0)
+			continue;
+
+		if (mask_isset(&lastlog_levels, iter->level))
+		    if (wild_match(pattern, iter->msg))
+			malloc_strcat_word_c(&retval, space, 
+					ltoa(line), DWORD_NO, &rvclue);
+		line++;
 	}
 
 	if (retval)
@@ -1086,14 +1098,14 @@ BUILT_IN_FUNCTION(function_lastlogctl, input)
 #endif
 
 /************************************************************************/
-#if 0
-int	oldest_lastlog_for_window (Lastlog **item, int winref)
+
+static int	oldest_lastlog_for_window (Lastlog **item, unsigned winref)
 {
 	*item = NULL;
 	return newer_lastlog_entry(item, winref);
 }
 
-int	newer_lastlog_entry (Lastlog **item, int winref)
+static int	newer_lastlog_entry (Lastlog **item, unsigned winref)
 {
 	Lastlog *i;
 
@@ -1109,7 +1121,7 @@ int	newer_lastlog_entry (Lastlog **item, int winref)
 	return i ? 1 : 0;
 }
 
-int	older_lastlog_entry (Lastlog **item, int winref)
+static int	older_lastlog_entry (Lastlog **item, unsigned winref)
 {
 	Lastlog *i;
 
@@ -1125,13 +1137,18 @@ int	older_lastlog_entry (Lastlog **item, int winref)
 	return i ? 1 : 0;
 }
 
-int	newest_lastlog_for_window (Lastlog **item, int winref)
+static int	newest_lastlog_for_window (Lastlog **item, unsigned winref)
 {
 	*item = NULL;
 	return older_lastlog_entry(item, winref);
 }
 
-int	remove_lastlog_item (Lastlog *item)
+/*
+ * Because this function does not have access to the window that this
+ * lastlog item belongs to *the caller* is responsible for adjusting
+ * window->lastlog_size!  I could change that in the future I guess
+ */
+static void	remove_lastlog_item (Lastlog *item)
 {
 	if (item == lastlog_oldest)
 	{
@@ -1139,7 +1156,8 @@ int	remove_lastlog_item (Lastlog *item)
 			panic(1, "Oldest lastlog item %jd has older item %jd",
 				item->refnum, item->older->refnum);
 
-		item->newer->older = NULL;
+		if (item->newer)
+			item->newer->older = NULL;
 		lastlog_oldest = item->newer;
 		item->newer = NULL;
 	}
@@ -1149,7 +1167,8 @@ int	remove_lastlog_item (Lastlog *item)
 			panic(1, "Newest lastlog item %jd has newer item %jd",
 				item->refnum, item->newer->refnum);
 
-		item->older->newer = NULL;
+		if (item->older)
+			item->older->newer = NULL;
 		lastlog_newest = item->older;
 		item->older = NULL;
 	}
@@ -1159,17 +1178,13 @@ int	remove_lastlog_item (Lastlog *item)
 		item->newer->older = item->older;
 		item->newer = item->older = NULL;
 	}
+
+	new_free((char **)&item->msg);
+	new_free((char **)&item->target);
+	new_free((char **)&item);
 }
 
-int	remove_oldest_lastlog_for_window (int winref)
-{
-	Lastlog *item = NULL;
-
-	if (oldest_lastlog_for_window(&item, winref))
-		remove_lastlog_item(item);
-}
-
-int	switch_lastlog_window (Lastlog *item, int newref)
+static void	switch_lastlog_window (Lastlog *item, unsigned newref)
 {
 	/* Mark the old window's scrollback for reconstitution */
 	window_scrollback_needs_rebuild(item->winref);
@@ -1177,5 +1192,107 @@ int	switch_lastlog_window (Lastlog *item, int newref)
 	/* Mark the new window's scrollback for reconstitution */
 	window_scrollback_needs_rebuild(item->winref);
 }
-#endif
+
+/***************************************************************************/
+static void	move_lastlog_item (Lastlog *item, unsigned newref)
+{
+	unsigned	oldref = item->winref;
+
+	item->winref = newref;
+	window_scrollback_needs_rebuild(oldref);
+	window_scrollback_needs_rebuild(newref);
+}
+
+void	move_all_lastlog (unsigned oldref, unsigned newref)
+{
+	Lastlog *l;
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref != oldref)
+			continue;
+		move_lastlog_item(l, newref);
+	}
+}
+
+void	move_lastlog_item_by_string (unsigned oldref, unsigned newref, const char *str)
+{
+	Lastlog *l;
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref != oldref)
+			continue;
+		if (!stristr(l->msg, str))
+			continue;
+		move_lastlog_item(l, newref);
+	}
+}
+
+void	move_lastlog_item_by_target (unsigned oldref, unsigned newref, const char *str)
+{
+	Lastlog *l;
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref != oldref)
+			continue;
+		if (!my_stricmp(l->target, str))
+			continue;
+		move_lastlog_item(l, newref);
+	}
+}
+
+void	move_lastlog_item_by_level (unsigned oldref, unsigned newref, Mask *levels)
+{
+	Lastlog *l;
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref != oldref)
+			continue;
+		if (!mask_isset(levels, l->level))
+			continue;
+		move_lastlog_item(l, newref);
+	}
+}
+
+void	move_lastlog_item_by_regex (unsigned oldref, unsigned newref, const char *str)
+{
+	Lastlog *l;
+	regex_t preg;
+	int	errcode;
+
+	errcode = regcomp(&preg, str, REG_EXTENDED | REG_ICASE | REG_NOSUB);
+	if (errcode != 0)
+	{
+		char	errstr[256];
+		regerror(errcode, &preg, errstr, sizeof(errstr));
+		say("Regular expression [%s] does not compile: %s", 
+			str, errstr);
+		return;
+	}
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref != oldref)
+			continue;
+		if (regexec(&preg, l->msg, 0, NULL, 0))
+			continue;
+		move_lastlog_item(l, newref);
+	}
+
+	regfree(&preg);
+}
+
+void	lastlog_swap_winrefs (unsigned oldref, unsigned newref)
+{
+	Lastlog *l;
+
+	for (l = lastlog_oldest; l; l = l->newer)
+	{
+		if (l->winref == oldref)
+			l->winref = newref;
+	}
+}
 
