@@ -1,4 +1,4 @@
-/* $EPIC: vars.c,v 1.104 2008/05/09 16:26:34 alex Exp $ */
+/* $EPIC: vars.c,v 1.107 2008/11/26 03:26:34 jnelson Exp $ */
 /*
  * vars.c: All the dealing of the irc variables are handled here. 
  *
@@ -279,79 +279,80 @@ void 	init_variables_stage1 (void)
 	VAR(CHANNEL_NAME_WIDTH, 	INT,  update_all_status_wrapper)
 #define DEFAULT_CLIENT_INFORMATION IRCII_COMMENT
 	VAR(CLIENT_INFORMATION, 	STR,  NULL)
-	VAR(CLOCK, 			BOOL, set_clock);
+	VAR(CLOCK, 			BOOL, my_set_clock);
 	VAR(CLOCK_24HOUR, 		BOOL, reset_clock);
 	VAR(CLOCK_FORMAT, 		STR,  set_clock_format);
 	VAR(CLOCK_INTERVAL, 		INT,  set_clock_interval);
 	VAR(CMDCHARS, 			STR,  NULL);
-	VAR(COMMENT_HACK, BOOL, NULL);
-	VAR(CONTINUED_LINE, STR,  NULL);
-	VAR(CPU_SAVER_AFTER, INT,  set_cpu_saver_after);
-	VAR(CPU_SAVER_EVERY, INT,  set_cpu_saver_every);
-	VAR(CURRENT_WINDOW_LEVEL, STR,  set_current_window_mask);
-	VAR(DCC_AUTO_SEND_REJECTS, BOOL, NULL);
-	VAR(DCC_DEQUOTE_FILENAMES, BOOL, NULL);
-	VAR(DCC_LONG_PATHNAMES, BOOL, NULL);
-	VAR(DCC_SLIDING_WINDOW, INT,  NULL);
-	VAR(DCC_STORE_PATH, STR,  NULL);
-	VAR(DCC_USE_GATEWAY_ADDR, BOOL, NULL)
+	VAR(COMMENT_HACK, 		BOOL, NULL);
+	VAR(CONTINUED_LINE, 		STR,  NULL);
+	VAR(CPU_SAVER_AFTER, 		INT,  set_cpu_saver_after);
+	VAR(CPU_SAVER_EVERY, 		INT,  set_cpu_saver_every);
+	VAR(CURRENT_WINDOW_LEVEL, 	STR,  set_current_window_mask);
+	VAR(DCC_AUTO_SEND_REJECTS, 	BOOL, NULL);
+	VAR(DCC_CONNECT_TIMEOUT,	INT,  NULL);
+	VAR(DCC_DEQUOTE_FILENAMES, 	BOOL, NULL);
+	VAR(DCC_LONG_PATHNAMES, 	BOOL, NULL);
+	VAR(DCC_SLIDING_WINDOW, 	INT,  NULL);
+	VAR(DCC_STORE_PATH, 		STR,  NULL);
+	VAR(DCC_USE_GATEWAY_ADDR, 	BOOL, NULL)
 #define DEFAULT_DEBUG 0
-	VAR(DEBUG, INT,  NULL);
+	VAR(DEBUG, 			INT,  NULL);
 #define DEFAULT_DEFAULT_REALNAME NULL
-	VAR(DEFAULT_REALNAME, STR,  NULL);
+	VAR(DEFAULT_REALNAME, 		STR,  NULL);
 #define DEFAULT_DEFAULT_USERNAME NULL
-	VAR(DEFAULT_USERNAME, STR, NULL);
-	VAR(DISPATCH_UNKNOWN_COMMANDS, BOOL, NULL);
-	VAR(DISPLAY, BOOL, NULL);
-	VAR(DO_NOTIFY_IMMEDIATELY, BOOL, NULL);
-	VAR(FLOATING_POINT_MATH, BOOL, NULL);
-	VAR(FLOATING_POINT_PRECISION, INT,  NULL);
-	VAR(FLOOD_AFTER, INT,  NULL);
-	VAR(FLOOD_IGNORE, BOOL, NULL);
-	VAR(FLOOD_MASKUSER, INT,  NULL);
-	VAR(FLOOD_RATE, INT,  NULL);
-	VAR(FLOOD_RATE_PER, INT,  NULL);
-	VAR(FLOOD_USERS, INT,  NULL);
-	VAR(FLOOD_WARNING, BOOL, NULL);
-	VAR(HIDE_PRIVATE_CHANNELS, BOOL, update_all_status_wrapper);
-	VAR(HIGH_BIT_ESCAPE, INT,  set_meta_8bit);
-	VAR(HOLD_SLIDER, INT,  NULL);
-	VAR(INDENT, BOOL, set_indent);
-        VAR(INPUT_INDICATOR_LEFT, STR, NULL);
-        VAR(INPUT_INDICATOR_RIGHT, STR, NULL);
-        VAR(INPUT_PROMPT, STR,  set_input_prompt);
-	VAR(INSERT_MODE, BOOL, update_all_status_wrapper);
-	VAR(KEY_INTERVAL, INT,  set_key_interval);
-	VAR(LASTLOG, INT,  set_lastlog_size);
-	VAR(LASTLOG_LEVEL, STR,  set_lastlog_mask);
-	VAR(LASTLOG_REWRITE, STR, NULL);
+	VAR(DEFAULT_USERNAME, 		STR, NULL);
+	VAR(DISPATCH_UNKNOWN_COMMANDS,	BOOL, NULL);
+	VAR(DISPLAY, 			BOOL, NULL);
+	VAR(DO_NOTIFY_IMMEDIATELY, 	BOOL, NULL);
+	VAR(FLOATING_POINT_MATH, 	BOOL, NULL);
+	VAR(FLOATING_POINT_PRECISION,	INT,  NULL);
+	VAR(FLOOD_AFTER, 		INT,  NULL);
+	VAR(FLOOD_IGNORE, 		BOOL, NULL);
+	VAR(FLOOD_MASKUSER,		INT,  NULL);
+	VAR(FLOOD_RATE,			INT,  NULL);
+	VAR(FLOOD_RATE_PER,		INT,  NULL);
+	VAR(FLOOD_USERS,		INT,  NULL);
+	VAR(FLOOD_WARNING,		BOOL, NULL);
+	VAR(HIDE_PRIVATE_CHANNELS,	BOOL, update_all_status_wrapper);
+	VAR(HIGH_BIT_ESCAPE,		INT,  set_meta_8bit);
+	VAR(HOLD_SLIDER,		INT,  NULL);
+	VAR(INDENT,			BOOL, set_indent);
+        VAR(INPUT_INDICATOR_LEFT,	STR, NULL);
+        VAR(INPUT_INDICATOR_RIGHT,	STR, NULL);
+        VAR(INPUT_PROMPT,		STR,  set_input_prompt);
+	VAR(INSERT_MODE,		BOOL, update_all_status_wrapper);
+	VAR(KEY_INTERVAL,		INT,  set_key_interval);
+	VAR(LASTLOG, 			INT,  set_lastlog_size);
+	VAR(LASTLOG_LEVEL,		STR,  set_lastlog_mask);
+	VAR(LASTLOG_REWRITE,		STR, NULL);
 #define DEFAULT_LOAD_PATH NULL
-	VAR(LOAD_PATH, STR,  NULL);
-	VAR(LOG, BOOL, logger);
-	VAR(LOGFILE, STR,  NULL);
+	VAR(LOAD_PATH,			STR,  NULL);
+	VAR(LOG,			BOOL, logger);
+	VAR(LOGFILE,			STR,  NULL);
 #define DEFAULT_LOG_REWRITE NULL
-	VAR(LOG_REWRITE, STR,  NULL);
-	VAR(MAIL, INT,  set_mail);
-	VAR(MAIL_INTERVAL, INT,  set_mail_interval);
-	VAR(MAIL_TYPE, STR, set_mail_type);
+	VAR(LOG_REWRITE,		STR,  NULL);
+	VAR(MAIL,			INT,  set_mail);
+	VAR(MAIL_INTERVAL,		INT,  set_mail_interval);
+	VAR(MAIL_TYPE,			STR, set_mail_type);
 #define DEFAULT_MANGLE_DISPLAY "NORMALIZE"
-	VAR(MANGLE_DISPLAY, STR,  set_mangle_display);
+	VAR(MANGLE_DISPLAY,		STR,  set_mangle_display);
 #define DEFAULT_MANGLE_INBOUND NULL
-	VAR(MANGLE_INBOUND, STR,  set_mangle_inbound);
+	VAR(MANGLE_INBOUND,		STR,  set_mangle_inbound);
 #define DEFAULT_MANGLE_LOGFILES NULL
-	VAR(MANGLE_LOGFILES, STR,  set_mangle_logfiles);
+	VAR(MANGLE_LOGFILES,		STR,  set_mangle_logfiles);
 #define DEFAULT_MANGLE_OUTBOUND NULL
-	VAR(MANGLE_OUTBOUND, STR,  set_mangle_outbound);
-	VAR(METRIC_TIME, BOOL, reset_clock);
-	VAR(MIRC_BROKEN_DCC_RESUME, BOOL, NULL);
-	VAR(MODE_STRIPPER, BOOL, NULL);
-	VAR(NEW_SERVER_LASTLOG_LEVEL, STR,  set_new_server_lastlog_mask);
-	VAR(NOTIFY, BOOL, set_notify);
-	VAR(NOTIFY_INTERVAL, INT,  set_notify_interval);
-	VAR(NOTIFY_LEVEL, STR,  set_notify_mask);
-	VAR(NOTIFY_ON_TERMINATION, BOOL, NULL);
-	VAR(NOTIFY_USERHOST_AUTOMATIC, BOOL, NULL);
-	VAR(NO_CONTROL_LOG, BOOL, NULL);	/* XXX /set mangle_logfile */
+	VAR(MANGLE_OUTBOUND,		STR,  set_mangle_outbound);
+	VAR(METRIC_TIME,		BOOL, reset_clock);
+	VAR(MIRC_BROKEN_DCC_RESUME,	BOOL, NULL);
+	VAR(MODE_STRIPPER,		BOOL, NULL);
+	VAR(NEW_SERVER_LASTLOG_LEVEL,	STR,  set_new_server_lastlog_mask);
+	VAR(NOTIFY,			BOOL, set_notify);
+	VAR(NOTIFY_INTERVAL,		INT,  set_notify_interval);
+	VAR(NOTIFY_LEVEL,		STR,  set_notify_mask);
+	VAR(NOTIFY_ON_TERMINATION,	BOOL, NULL);
+	VAR(NOTIFY_USERHOST_AUTOMATIC,	BOOL, NULL);
+	VAR(NO_CONTROL_LOG,		BOOL, NULL);	/* XXX /set mangle_logfile */
 	VAR(NO_CTCP_FLOOD, BOOL, NULL);
 	VAR(NO_FAIL_DISCONNECT, BOOL, NULL);
 	VAR(OLD_MATH_PARSER, BOOL, NULL);
