@@ -1,4 +1,4 @@
-/* $EPIC: who.c,v 1.59 2007/05/25 16:47:48 jnelson Exp $ */
+/* $EPIC: who.c,v 1.63 2008/05/09 17:06:10 jnelson Exp $ */
 /*
  * who.c -- The WHO queue.  The ISON queue.  The USERHOST queue.
  *
@@ -44,7 +44,7 @@
 #include "output.h"
 #include "numbers.h"
 #include "parse.h"
-#include "if.h"
+#include "ifcmd.h"
 #include "names.h"
 #include "words.h"
 #include "reg.h"
@@ -1127,27 +1127,39 @@ static void ison_queue_send (int refnum)
 	send_to_aserver(refnum, "ISON %s", save->ison_asked);
 }
 
+static void ison_entry_pop (IsonEntry **entry)
+{
+	IsonEntry *save = (*entry)->next;
+
+	new_free(&(*entry)->ison_asked);
+	new_free(&(*entry)->ison_got);
+	new_free(&(*entry)->oncmd);
+	new_free(&(*entry)->offcmd);
+	new_free(&(*entry)->endcmd);
+	new_free((char **)entry);
+	*entry = save;
+	return;
+}
+
 static void ison_queue_pop (int refnum)
 {
 	Server *s;
-	IsonEntry *save;
 
 	if (!(s = get_server(refnum)))
 		return;
 
-	if ((save = s->ison_queue))
-	{
-		s->ison_queue = save->next;
-		new_free(&save->ison_asked);
-		new_free(&save->ison_got);
-		new_free(&save->oncmd);
-		new_free(&save->offcmd);
-		new_free(&save->endcmd);
-		new_free((char **)&save);
-	}
-	return;
+	ison_entry_pop(&(s->ison_queue));
 }
 
+static void ison_wait_pop (int refnum)
+{
+	Server *s;
+
+	if (!(s = get_server(refnum)))
+		return;
+
+	ison_entry_pop(&(s->ison_wait));
+}
 static IsonEntry *ison_queue_top (int refnum)
 {
 	Server *s;
@@ -1158,6 +1170,16 @@ static IsonEntry *ison_queue_top (int refnum)
 	return s->ison_queue;
 }
 
+static IsonEntry *ison_wait_top (int refnum)
+{
+	Server *s;
+
+	if (!(s = get_server(refnum)))
+		return NULL;
+
+	return s->ison_wait;
+}
+
 static IsonEntry *get_new_ison_entry (int refnum, int next)
 {
 	Server *s;
@@ -1211,7 +1233,7 @@ BUILT_IN_COMMAND(isoncmd)
 void	isonbase (int refnum, char *args, void (*line) (int, char *, char *))
 {
 	IsonEntry 	*new_i;
-	char 		*next = args;
+	char 		*next = args, *restore = NULL;
 	char		*on_cmd = NULL, *offcmd = NULL, *endcmd = NULL;
 	int		sendnext = 0;
 
@@ -1232,6 +1254,8 @@ void	isonbase (int refnum, char *args, void (*line) (int, char *, char *))
 		{
 			while (ison_queue_top(from_server))
 				ison_queue_pop(from_server);
+			while (ison_wait_top(from_server))
+				ison_wait_pop(from_server);
 		}
 		if (!my_stricmp(arg, "-s"))
 		{
@@ -1296,6 +1320,7 @@ void	isonbase (int refnum, char *args, void (*line) (int, char *, char *))
 			next = args + get_server(refnum)->ison_len;
 			while (!isspace(*next))
 				next--;
+			restore = next;
 			*next++ = 0;
 		}
 		else
@@ -1307,6 +1332,8 @@ void	isonbase (int refnum, char *args, void (*line) (int, char *, char *))
 		if (!next)
 			malloc_strcpy(&new_i->endcmd, endcmd);
 		ison_queue_send(refnum);
+		if (restore)
+			*restore = ' ';
 	}
 }
 
@@ -1388,6 +1415,16 @@ static UserhostEntry *userhost_queue_top (int refnum)
 	return s->userhost_queue;
 }
 
+static UserhostEntry *userhost_wait_top (int refnum)
+{
+	Server *s;
+
+	if (!(s = get_server(refnum)))
+		return NULL;
+
+	return s->userhost_wait;
+}
+
 static void userhost_queue_add (int refnum, UserhostEntry *item)
 {
 	UserhostEntry *bottom;
@@ -1443,20 +1480,35 @@ static void userhost_queue_send (int refnum)
 	send_to_aserver(refnum, save->format, save->userhost_asked);
 }
 
+static void userhost_entry_pop (UserhostEntry **entry)
+{
+	UserhostEntry *save = (*entry)->next;
+
+	new_free(&(*entry)->userhost_asked);
+	new_free(&(*entry)->text);
+	new_free((char **)entry);
+	*entry = save;
+	return;
+}
+
 static void userhost_queue_pop (int refnum)
 {
-	UserhostEntry *save;
 	Server *s;
 
 	if (!(s = get_server(refnum)))
 		return;
 
-	save = s->userhost_queue;
-	s->userhost_queue = save->next;
-	new_free(&save->userhost_asked);
-	new_free(&save->text);
-	new_free((char **)&save);
-	return;
+	userhost_entry_pop(&(s->userhost_queue));
+}
+
+static void userhost_wait_pop (int refnum)
+{
+	Server *s;
+
+	if (!(s = get_server(refnum)))
+		return;
+
+	userhost_entry_pop(&(s->userhost_wait));
 }
 
 static UserhostEntry *get_new_userhost_entry (int refnum)
@@ -1563,6 +1615,12 @@ void userhostbase (int refnum, char *args, const char *subargs, void (*line) (in
 			/* XXX But what if extravar contains []s? */
 			extra = get_variable(extravar);
 		}
+		else if (!my_strnicmp(nick, "-flush", 2))
+		{
+			while (userhost_wait_top(refnum))
+				userhost_wait_pop(refnum);
+			return;
+		}
 	}
 
 	if (!userhost_cmd && !total)
